Trait State Copy item path Source pub trait State: Sized {
Show 18 associated items type Name ;
type NoiseProtocols ;
type Keypair ;
type Bind ;
type Parties ;
type PeerBudget ;
type MaxMessageSize ;
type ConnectRetryDelays ;
type SendRetryDelays ;
type RandomConnectDelay ;
type ConnectTimeout ;
type HandshakeTimeout ;
type ReceiveTimeout ;
type BackoffDuration ;
type KeepAliveAfter ;
type KeepAliveInterval ;
type KeepAliveRetries ;
type Metrics ;
}Expand description Builder’s type state specifies if members are set or not (unset).
You can use the associated types of this trait to control the state of individual members with the IsSet and IsUnset traits. You can change the state of the members with the Set* structs available in this module.
Type state of the member name.
It can implement either IsSet or IsUnset
Type state of the member noise_protocols.
It can implement either IsSet or IsUnset
Type state of the member keypair.
It can implement either IsSet or IsUnset
Type state of the member bind.
It can implement either IsSet or IsUnset
Type state of the member parties.
It can implement either IsSet or IsUnset
Type state of the member peer_budget.
It can implement either IsSet or IsUnset
Type state of the member max_message_size.
It can implement either IsSet or IsUnset
Type state of the member connect_retry_delays.
It can implement either IsSet or IsUnset
Type state of the member send_retry_delays.
It can implement either IsSet or IsUnset
Type state of the member random_connect_delay.
It can implement either IsSet or IsUnset
Type state of the member connect_timeout.
It can implement either IsSet or IsUnset
Type state of the member handshake_timeout.
It can implement either IsSet or IsUnset
Type state of the member receive_timeout.
It can implement either IsSet or IsUnset
Type state of the member backoff_duration.
It can implement either IsSet or IsUnset
Type state of the member keep_alive_after.
It can implement either IsSet or IsUnset
Type state of the member keep_alive_interval.
It can implement either IsSet or IsUnset
Type state of the member keep_alive_retries.
It can implement either IsSet or IsUnset
Type state of the member metrics.
It can implement either IsSet or IsUnset
This trait is not dyn compatible .
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.